@@ -11,13 +11,14 @@
 
 import codecs
 from os import path
-from typing import TYPE_CHECKING
+from typing import cast
 
 from six import iteritems
 
 from sphinx import package_dir
 from sphinx.builders import Builder
-from sphinx.locale import _
+from sphinx.domains.changeset import ChangeSetDomain
+from sphinx.locale import _, __
 from sphinx.theming import HTMLThemeFactory
 from sphinx.util import logging
 from sphinx.util.console import bold  # type: ignore
@@ -25,7 +26,8 @@ from sphinx.util.fileutil import copy_asset_file
 from sphinx.util.osutil import ensuredir, os_path
 from sphinx.util.pycompat import htmlescape
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Any, Dict, List, Tuple  # NOQA
     from sphinx.application import Sphinx  # NOQA
 
@@ -38,7 +40,7 @@ class ChangesBuilder(Builder):
     Write a summary with all versionadded/changed directives.
     """
     name = 'changes'
-    epilog = 'The overview file is in %(outdir)s.'
+    epilog = __('The overview file is in %(outdir)s.')
 
     def init(self):
         # type: () -> None
@@ -60,28 +62,30 @@ class ChangesBuilder(Builder):
     def write(self, *ignored):
         # type: (Any) -> None
         version = self.config.version
+        domain = cast(ChangeSetDomain, self.env.get_domain('changeset'))
         libchanges = {}     # type: Dict[unicode, List[Tuple[unicode, unicode, int]]]
         apichanges = []     # type: List[Tuple[unicode, unicode, int]]
         otherchanges = {}   # type: Dict[Tuple[unicode, unicode], List[Tuple[unicode, unicode, int]]]  # NOQA
         if version not in self.env.versionchanges:
-            logger.info(bold('no changes in version %s.' % version))
+            logger.info(bold(__('no changes in version %s.') % version))
             return
         logger.info(bold('writing summary file...'))
-        for type, docname, lineno, module, descname, content in \
-                self.env.versionchanges[version]:
-            if isinstance(descname, tuple):
-                descname = descname[0]
-            ttext = self.typemap[type]
-            context = content.replace('\n', ' ')
-            if descname and docname.startswith('c-api'):
+        for changeset in domain.get_changesets_for(version):
+            if isinstance(changeset.descname, tuple):
+                descname = changeset.descname[0]
+            else:
+                descname = changeset.descname
+            ttext = self.typemap[changeset.type]
+            context = changeset.content.replace('\n', ' ')
+            if descname and changeset.docname.startswith('c-api'):
                 if context:
                     entry = '<b>%s</b>: <i>%s:</i> %s' % (descname, ttext,
                                                           context)
                 else:
                     entry = '<b>%s</b>: <i>%s</i>.' % (descname, ttext)
-                apichanges.append((entry, docname, lineno))
-            elif descname or module:
-                if not module:
+                apichanges.append((entry, changeset.docname, changeset.lineno))
+            elif descname or changeset.module:
+                if not changeset.module:
                     module = _('Builtins')
                 if not descname:
                     descname = _('Module level')
@@ -90,15 +94,15 @@ class ChangesBuilder(Builder):
                                                           context)
                 else:
                     entry = '<b>%s</b>: <i>%s</i>.' % (descname, ttext)
-                libchanges.setdefault(module, []).append((entry, docname,
-                                                          lineno))
+                libchanges.setdefault(module, []).append((entry, changeset.docname,
+                                                          changeset.lineno))
             else:
                 if not context:
                     continue
                 entry = '<i>%s:</i> %s' % (ttext.capitalize(), context)
-                title = self.env.titles[docname].astext()
-                otherchanges.setdefault((docname, title), []).append(
-                    (entry, docname, lineno))
+                title = self.env.titles[changeset.docname].astext()
+                otherchanges.setdefault((changeset.docname, title), []).append(
+                    (entry, changeset.docname, changeset.lineno))
 
         ctx = {
             'project': self.config.project,
@@ -129,14 +133,14 @@ class ChangesBuilder(Builder):
                     break
             return line
 
-        logger.info(bold('copying source files...'))
+        logger.info(bold(__('copying source files...')))
         for docname in self.env.all_docs:
             with codecs.open(self.env.doc2path(docname), 'r',  # type: ignore
                              self.env.config.source_encoding) as f:
                 try:
                     lines = f.readlines()
                 except UnicodeDecodeError:
-                    logger.warning('could not read %r for changelog creation', docname)
+                    logger.warning(__('could not read %r for changelog creation'), docname)
                     continue
             targetfn = path.join(self.outdir, 'rst', os_path(docname)) + '.html'
             ensuredir(path.dirname(targetfn))
