@@ -5,7 +5,7 @@
 
     Build HTML documentation and Devhelp_ support files.
 
-    .. _Devhelp: http://live.gnome.org/devhelp
+    .. _Devhelp: https://wiki.gnome.org/Apps/Devhelp
 
     :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
@@ -15,13 +15,13 @@ from __future__ import absolute_import
 import gzip
 import re
 from os import path
-from typing import TYPE_CHECKING
 
 from docutils import nodes
 
 from sphinx import addnodes
 from sphinx.builders.html import StandaloneHTMLBuilder
 from sphinx.environment.adapters.indexentries import IndexEntries
+from sphinx.locale import __
 from sphinx.util import logging
 from sphinx.util.osutil import make_filename
 
@@ -30,7 +30,8 @@ try:
 except ImportError:
     import lxml.etree as etree  # type: ignore
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Any, Dict, List  # NOQA
     from sphinx.application import Sphinx  # NOQA
 
@@ -43,10 +44,10 @@ class DevhelpBuilder(StandaloneHTMLBuilder):
     Builder that also outputs GNOME Devhelp file.
     """
     name = 'devhelp'
-    epilog = ('To view the help file:\n'
-              '$ mkdir -p $HOME/.local/share/devhelp/%(project)s\n'
-              '$ ln -s %(outdir)s $HOME/.local/share/devhelp/%(project)s\n'
-              '$ devhelp')
+    epilog = __('To view the help file:\n'
+                '$ mkdir -p $HOME/.local/share/devhelp/books\n'
+                '$ ln -s $PWD/%(outdir)s $HOME/.local/share/devhelp/books/%(project)s\n'
+                '$ devhelp')
 
     # don't copy the reST source
     copysource = False
@@ -69,7 +70,7 @@ class DevhelpBuilder(StandaloneHTMLBuilder):
 
     def build_devhelp(self, outdir, outname):
         # type: (unicode, unicode) -> None
-        logger.info('dumping devhelp index...')
+        logger.info(__('dumping devhelp index...'))
 
         # Basic info
         root = etree.Element('book',
